@@ -1,10 +1,10 @@
 #! /usr/bin/env node
 
-var mqtt = require('../')
+const mqtt = require('../')
 
-var client = mqtt.connect({ port: 1883, host: 'localhost', clean: true, encoding: 'binary', keepalive: 0 })
-var counter = 0
-var interval = 5000
+const client = mqtt.connect({ port: 1883, host: 'localhost', clean: true, encoding: 'binary', keepalive: 0 })
+let counter = 0
+const interval = 5000
 
 function count () {
   console.log('received/s', counter / interval * 1000)
