@@ -3,11 +3,11 @@
 /**
  * Module dependencies
  */
-var xtend = require('xtend')
+const xtend = require('xtend')
 
-var Readable = require('readable-stream').Readable
-var streamsOpts = { objectMode: true }
-var defaultStoreOptions = {
+const Readable = require('readable-stream').Readable
+const streamsOpts = { objectMode: true }
+const defaultStoreOptions = {
   clean: true
 }
 
@@ -50,10 +50,10 @@ Store.prototype.put = function (packet, cb) {
  *
  */
 Store.prototype.createStream = function () {
-  var stream = new Readable(streamsOpts)
-  var destroyed = false
-  var values = []
-  var i = 0
+  const stream = new Readable(streamsOpts)
+  const values = []
+  let destroyed = false
+  let i = 0
 
   this._inflights.forEach(function (value, key) {
     values.push(value)
@@ -72,7 +72,7 @@ Store.prototype.createStream = function () {
       return
     }
 
-    var self = this
+    const self = this
 
     destroyed = true
 
