@@ -10,9 +10,9 @@
  * @returns {Boolean} If the topic is valid, returns true. Otherwise, returns false.
  */
 function validateTopic (topic) {
-  var parts = topic.split('/')
+  const parts = topic.split('/')
 
-  for (var i = 0; i < parts.length; i++) {
+  for (let i = 0; i < parts.length; i++) {
     if (parts[i] === '+') {
       continue
     }
@@ -39,7 +39,7 @@ function validateTopics (topics) {
   if (topics.length === 0) {
     return 'empty_topic_list'
   }
-  for (var i = 0; i < topics.length; i++) {
+  for (let i = 0; i < topics.length; i++) {
     if (!validateTopic(topics[i])) {
       return topics[i]
     }
