@@ -1,11 +1,11 @@
 'use strict'
 
-var MqttServer = require('../server').MqttServer
-var MqttSecureServer = require('../server').MqttSecureServer
-var fs = require('fs')
+const MqttServer = require('../server').MqttServer
+const MqttSecureServer = require('../server').MqttSecureServer
+const fs = require('fs')
 
 module.exports.init_server = function (PORT) {
-  var server = new MqttServer(function (client) {
+  const server = new MqttServer(function (client) {
     client.on('connect', function () {
       client.connack(0)
     })
@@ -13,10 +13,10 @@ module.exports.init_server = function (PORT) {
     client.on('publish', function (packet) {
       switch (packet.qos) {
         case 1:
-          client.puback({messageId: packet.messageId})
+          client.puback({ messageId: packet.messageId })
           break
         case 2:
-          client.pubrec({messageId: packet.messageId})
+          client.pubrec({ messageId: packet.messageId })
           break
         default:
           break
@@ -24,7 +24,7 @@ module.exports.init_server = function (PORT) {
     })
 
     client.on('pubrel', function (packet) {
-      client.pubcomp({messageId: packet.messageId})
+      client.pubcomp({ messageId: packet.messageId })
     })
 
     client.on('pingreq', function () {
@@ -40,12 +40,12 @@ module.exports.init_server = function (PORT) {
 }
 
 module.exports.init_secure_server = function (port, key, cert) {
-  var server = new MqttSecureServer({
+  const server = new MqttSecureServer({
     key: fs.readFileSync(key),
     cert: fs.readFileSync(cert)
   }, function (client) {
     client.on('connect', function () {
-      client.connack({returnCode: 0})
+      client.connack({ returnCode: 0 })
     })
   })
   server.listen(port)
