@@ -1,6 +1,6 @@
 'use strict'
 
-var mqtt = require('../lib/connect')
+const mqtt = require('../lib/connect')
 
 describe('store in lib/connect/index.js (webpack entry point)', function () {
   it('should create store', function (done) {
