@@ -1,7 +1,7 @@
 'use strict'
 
-var Store = require('../lib/store')
-var abstractTest = require('../test/abstract_store')
+const Store = require('../lib/store')
+const abstractTest = require('../test/abstract_store')
 
 describe('in-memory store', function () {
   abstractTest(function (done) {
